==> magique_ai-0.1.7-py3-none-any.whl: tests/test_file_manager.py <==
import os
from magique.ai.tools.file_transfer.client import FileTransferClient
from magique.ai.tools.file_transfer.worker import FileTransferToolSet
from magique.ai.tools.file_manager import FileManagerToolSet
from magique.ai.toolset import run_toolsets
from magique.ai import connect_remote
from tempfile import TemporaryDirectory


async def test_file_transfer():
    test_file = "test.txt"
    with open(test_file, "w") as f:
        f.write("Hello, world!")

    test_output_file = "test_output.txt"
    with TemporaryDirectory() as temp_dir:
        toolset = FileTransferToolSet("file_manager", temp_dir)
        async with run_toolsets([toolset]):
            client = FileTransferClient(toolset.service_id, connect_params={"try_direct_connection": False})
            await client.send_file(test_file, "test.txt", chunk_size=10000)
            await client.fetch_file(test_output_file, "test.txt", chunk_size=10000)
            with open(test_output_file, "r") as f:
                assert f.read() == "Hello, world!"

    os.remove(test_file)
    os.remove(test_output_file)


async def test_file_manager():
    with TemporaryDirectory() as temp_dir:
        toolset = FileManagerToolSet("file_manager", temp_dir)
        async with run_toolsets([toolset]):
            service = await connect_remote(toolset.service_id)
            await service.invoke("create_directory", {"sub_dir": "test1"})
            await service.invoke("create_directory", {"sub_dir": "test2"})
            await service.invoke("write_file", {"file_name": "test.txt", "content": "Hello, world!1"})
            await service.invoke("write_file", {"file_name": "test1/test.txt", "content": "Hello, world!2"})
            await service.invoke("write_file", {"file_name": "test2/test.txt", "content": "Hello, world!3"})
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 3
            resp = await service.invoke("read_file", {"file_name": "test.txt"})
            assert resp["content"] == "Hello, world!1"
            resp = await service.invoke("read_file", {"file_name": "test1/test.txt"})
            assert resp["content"] == "Hello, world!2"
            resp = await service.invoke("read_file", {"file_name": "test2/test.txt"})
            assert resp["content"] == "Hello, world!3"
            resp = await service.invoke("delete_file", {"file_name": "test.txt"})
            assert resp["success"]
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 2
            resp = await service.invoke("delete_directory", {"sub_dir": "test1"})
            assert resp["success"]
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 1
            resp = await service.invoke("delete_directory", {"sub_dir": "test2"})
            assert resp["success"]
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 0

            # error cases
            resp = await service.invoke("delete_directory", {"sub_dir": "test1"})
            assert not resp["success"]
            resp = await service.invoke("delete_directory", {"sub_dir": "test1/test.txt"})
            assert not resp["success"]
            resp = await service.invoke("delete_file", {"file_name": "../test.txt"})
            assert not resp["success"]

==> magique_ai-0.2.4-py3-none-any.whl: tests/test_file_manager.py <==
import os
from magique.ai.tools.file_transfer.client import FileTransferClient
from magique.ai.tools.file_transfer.worker import FileTransferToolSet
from magique.ai.tools.file_manager import FileManagerToolSet
from magique.ai.toolset import run_toolsets
from magique.ai import connect_remote
from tempfile import TemporaryDirectory


async def test_file_transfer():
    test_file = "test.txt"
    with open(test_file, "w") as f:
        f.write("Hello, world!")

    test_output_file = "test_output.txt"
    with TemporaryDirectory() as temp_dir:
        toolset = FileTransferToolSet("file_transfer", temp_dir)
        async with run_toolsets([toolset]):
            client = FileTransferClient(toolset.service_id, connect_params={"try_direct_connection": False})
            await client.send_file(test_file, "test.txt", chunk_size=10000)
            await client.fetch_file(test_output_file, "test.txt", chunk_size=10000)
            with open(test_output_file, "r") as f:
                assert f.read() == "Hello, world!"

    os.remove(test_file)
    os.remove(test_output_file)


async def test_file_manager():
    with TemporaryDirectory() as temp_dir:
        toolset = FileManagerToolSet("file_manager", temp_dir)
        async with run_toolsets([toolset]):
            service = await connect_remote(toolset.service_id)
            await service.invoke("create_directory", {"sub_dir": "test1"})
            await service.invoke("create_directory", {"sub_dir": "test2"})
            await service.invoke("write_file", {"file_name": "test.txt", "content": "Hello, world!1"})
            await service.invoke("write_file", {"file_name": "test1/test.txt", "content": "Hello, world!2"})
            await service.invoke("write_file", {"file_name": "test2/test.txt", "content": "Hello, world!3"})
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 3
            resp = await service.invoke("read_file", {"file_name": "test.txt"})
            assert resp["content"] == "Hello, world!1"
            resp = await service.invoke("read_file", {"file_name": "test1/test.txt"})
            assert resp["content"] == "Hello, world!2"
            resp = await service.invoke("read_file", {"file_name": "test2/test.txt"})
            assert resp["content"] == "Hello, world!3"
            resp = await service.invoke("delete_file", {"file_name": "test.txt"})
            assert resp["success"]
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 2
            resp = await service.invoke("delete_directory", {"sub_dir": "test1"})
            assert resp["success"]
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 1
            resp = await service.invoke("delete_directory", {"sub_dir": "test2"})
            assert resp["success"]
            resp = await service.invoke("list_file_tree")
            assert len(resp['children']) == 0

            # error cases
            resp = await service.invoke("delete_directory", {"sub_dir": "test1"})
            assert not resp["success"]
            resp = await service.invoke("delete_directory", {"sub_dir": "test1/test.txt"})
            assert not resp["success"]
            resp = await service.invoke("delete_file", {"file_name": "../test.txt"})
            assert not resp["success"]
